@@ -1,5 +1,5 @@
 extern crate trade_aggregation;
-use trade_aggregation::{aggregate_all_trades, load_trades_from_csv, H1, TimeAggregator};
+use trade_aggregation::{aggregate_all_trades, load_trades_from_csv, TimeAggregator, H1};
 
 fn main() {
     // load trades from file
