@@ -1,4 +1,4 @@
-use trade_aggregation::{By, load_trades_from_csv, ModularVolumeAggregator, FeatureModules};
+use trade_aggregation::{load_trades_from_csv, By, FeatureModules, ModularVolumeAggregator};
 
 fn main() {
     // load trades from file
@@ -14,8 +14,8 @@ fn main() {
             Some(candle) => {
                 // do something with the latest candle
                 println!("candle: {:?}", candle);
-            },
+            }
             None => {}
         }
     }
-}
\ No newline at end of file
+}
